@@ -56,13 +56,12 @@ context_init(context, parent)
   (*context)->treerowref = NULL;
   (*context)->move_menuitem = NULL;
   (*context)->plugin_prefs_widget = NULL;
-  (*context)->plugin_prefs_cred_swindow = NULL;
-  (*context)->plugin_prefs_cred_vbox = NULL;
+  (*context)->plugin_prefs_cred_widget = NULL;
   (*context)->pbar = NULL;
   (*context)->plugin_tree_store = NULL;
   (*context)->plugin_tree_model = NULL;
+#endif  
   (*context)->plugin_cache_loaded = 0;
-#endif
 }
 
 struct context *
@@ -113,13 +112,9 @@ context_force_plugin_prefs_redraw(struct context *context)
     g_object_unref(context->plugin_prefs_widget);
     context->plugin_prefs_widget = NULL;
   }
-  if (context->plugin_prefs_cred_swindow != NULL) {
-    g_object_unref(context->plugin_prefs_cred_swindow);
-    context->plugin_prefs_cred_swindow = NULL;
-  }
-  if (context->plugin_prefs_cred_vbox != NULL) {
-    g_object_unref(context->plugin_prefs_cred_vbox);
-    context->plugin_prefs_cred_vbox = NULL;
+  if (context->plugin_prefs_cred_widget != NULL) {
+    g_object_unref(context->plugin_prefs_cred_widget);
+    context->plugin_prefs_cred_widget = NULL;
   }
 #endif
 }
@@ -186,7 +181,6 @@ context_set_plugins_md5sum(struct context *context, const char *md5sum)
   context->plugins_md5sum = estrdup(md5sum);
 }
 
-#ifdef USE_GTK
 struct context **
 context_find_child_ptr(context, child)
   struct context *context;
@@ -744,4 +738,3 @@ check_is_dir(name)
   else
     return(S_ISDIR(sb.st_mode));
 }
-#endif /* USE_GTK */
