@@ -12,10 +12,6 @@ extern int ListOnly;
 #ifdef _WIN32
 # include "globals.w32"
 /* #define _NO_PIES */
-#else /* _WIN32 */
-#ifndef NESSUS_ON_SSL
-# define closesocket(x) close (x)
-#endif
 #endif /* _WIN32 */
 
 # define HANDLE int
