@@ -142,9 +142,11 @@ static int risk_severity(hosts, risks)
  float *risks;
 { 
  int i;
- for ( i = 0; i < 3 ; i ++ ) risks[i] = 0;
- if ( hosts == NULL );
 
+ if ( hosts == NULL )
+   return 0;
+
+ for ( i = 0; i < 3 ; i ++ ) risks[i] = 0;
  while( hosts->next != NULL )
  {
   risk_severity_by_host(hosts->value, risks);
