@@ -35,6 +35,8 @@
 #include <gtk/gtk.h>
 #include "prefs_dialog/prefs_dialog.h"
 #include "prefs_dialog/prefs_context.h"
+#else
+#include <glib.h>
 #endif
 
 #include "error_dlg.h"
@@ -50,7 +52,6 @@
 #include "preferences.h"
 #include "globals.h"
 #include "corevers.h"
-#include <getopt.h>
 #include "filter.h"
 
 #include "backend.h"
@@ -59,23 +60,14 @@
 #include "html_graph_output.h"
 #include "latex_output.h"
 #include "text_output.h"
-#include "xml_output.h"
 #include "xml_output_ng.h"
 #include "plugin_cache.h"
 
 #include "cli.h"
 
-#ifdef HAVE_SSL
 #include <openssl/x509v3.h>
-#endif
 
-#ifdef USE_AF_UNIX
-#undef NESSUS_ON_SSL
-#endif
-
-#ifdef NESSUS_ON_SSL
 #include "sslui.h"
-#endif
 
 #ifndef INADDR_NONE
 #define INADDR_NONE 0xFFFFFFFF
@@ -88,17 +80,13 @@
 struct arglist * MainDialog;
 char * Alt_rcfile = NULL;
 struct plugin_filter Filter;
-int DontCheckServerCert = 0;
+static gboolean dont_check_ssl_cert = FALSE;
+gboolean quiet_mode = FALSE;
+gboolean show_pixmaps = FALSE;
 int F_show_pixmaps;
 int F_quiet_mode;
 int ListOnly = 0;
 
-#ifndef USE_AF_INET      
-#undef ENABLE_CRYPTO_LAYER
-#endif
-
-
-
 void init_globals();
 
 /*
@@ -129,7 +117,6 @@ i18n_init(void)
 }
 
 
-#ifdef NESSUS_ON_SSL
 #define CLN_AUTH_SRV 1
 
 static int
@@ -142,7 +129,6 @@ verify_callback(preverify_ok, ctx)
 #endif
   return preverify_ok;
 }
-#endif
 
 
 
@@ -343,7 +329,6 @@ connect_to_nessusd(context)
    * 3: trust CA & check certificate
    */      
 #endif
-#ifdef NESSUS_ON_SSL
   static SSL_CTX	*ssl_ctx = NULL;
   static SSL_METHOD	*ssl_mt = NULL;
   SSL		*ssl = NULL;
@@ -352,19 +337,15 @@ connect_to_nessusd(context)
   STACK_OF(X509_NAME)	*cert_names;
   int use_client_cert = prefs_get_int(context, "use_client_cert");
   char *pem_pass = NULL;
-#endif
   int soc, soc2;
   int opt;
-#ifndef USE_AF_INET
-  struct sockaddr_un address;
-  char * name = AF_UNIX_PATH;
-#endif
   const char *passwd;
   /* Initialize the array with a string that will be big enough */
   char proto[] = PROTO_NAME "md5_caching";
 
-  if (snprintf(proto, sizeof(proto), PROTO_NAME,
-	  prefs_get_int(Global, "cache_plugin_information") ? "md5_caching":"")
+  if (snprintf(proto, sizeof(proto),
+      prefs_get_int(context, "protocol_version") ? PROTO_NAME_OTP : PROTO_NAME,
+      prefs_get_int(Global, "cache_plugin_information") ? "md5_caching":"")
       >= sizeof(proto))
     return "programming error: proto_name buffer too small";
 
@@ -381,7 +362,6 @@ connect_to_nessusd(context)
   port = prefs_get_int(context, "nessusd_port");
   login = prefs_get_string(context, "nessusd_user");
 
-#ifdef USE_AF_INET
   soc = open_sock_tcp_hn(hostname, port);
   
   
@@ -400,38 +380,16 @@ connect_to_nessusd(context)
 	
   opt = 1;	
   setsockopt(soc, SOL_SOCKET, SO_KEEPALIVE, &opt, sizeof(opt));
- 
-#else
-  if((soc = socket(AF_UNIX, SOCK_STREAM,0))==-1){
-  	perror("socket ");
-  	exit(1);
-  	}
-  bzero(&address, sizeof(struct sockaddr_un));
-  address.sun_family = AF_UNIX;
-  bcopy(name, address.sun_path, strlen(name));
-  if(connect(soc, (struct sockaddr*)&address, sizeof(address))==-1)
-  {
-	char * error = emalloc(255+strlen(name)+strlen(strerror(errno)));
-	sprintf(error, _("Could not connect to %s - %s\n"), name, strerror(errno));
-	return error;
-  }
-#endif  
 
-#ifdef NESSUS_ON_SSL
-  if (prefs_get_int(context, "use_ssl"))
-  {
-    ssl_ver = prefs_get_string(context, "ssl_version");
-    if (!strcasecmp(ssl_ver, "NONE"))
-      ssl_ver = prefs_get_default(context, "ssl_version");
-  }
-  else
-    ssl_ver = "NONE";
+  ssl_ver = prefs_get_string(context, "ssl_version");
+  if (!strcasecmp(ssl_ver, "NONE"))
+    ssl_ver = prefs_get_default(context, "ssl_version");
 
   if (strcasecmp(ssl_ver, "NONE") != 0)
     {
 #ifdef CLN_AUTH_SRV
       paranoia_level = prefs_get_int(context, "paranoia_level");
-      if(!paranoia_level && !DontCheckServerCert)
+      if(!paranoia_level && !dont_check_ssl_cert)
       {
 	paranoia_level = sslui_ask_paranoia_level();
 	if(paranoia_level >= 1 && paranoia_level <= 3)
@@ -442,7 +400,7 @@ connect_to_nessusd(context)
       if(nessus_SSL_init(NULL) < 0)
 	{
 	  return(_("Could not initialize the OpenSSL library !\n\
-Please launch nessusclient-mkrand(1) first !"));
+Please launch openvasclient-mkrand(1) first !"));
 	}
       if (ssl_mt == NULL)
 	{
@@ -589,7 +547,7 @@ Please launch nessusclient-mkrand(1) first !"));
 #endif
 
 #ifdef CLN_AUTH_SRV
-      if (DontCheckServerCert == 0 && (paranoia_level == 1 || paranoia_level == 3))
+      if (!dont_check_ssl_cert && (paranoia_level == 1 || paranoia_level == 3))
 	{
 	  X509	*cert = SSL_get_peer_certificate(ssl);
 	  char	stored_hash[SHA_DIGEST_LENGTH];
@@ -632,38 +590,21 @@ Please launch nessusclient-mkrand(1) first !"));
   stream_set_buffer(soc2, 1024 * 1024);
   soc = soc2;
   
-#else 
-  if((soc2 = nessus_register_connection(soc, NULL)) < 0)
-   {
-    efree(&passwd);
-    return _("Could not register the connection");
-   }
-  stream_set_buffer(soc2, 1024 * 1024);
-   soc = soc2;
-#endif 
   context->socket = soc;
 
   if(comm_init(context->socket, proto) || (auth_login(context->socket, login, passwd)))
     {
-#ifdef NESSUS_ON_SSL
       close_stream_connection(context->socket);
       efree(&pem_pass);
-#else
-      shutdown(context->socket, 2);
-#endif
       context->socket = -1;
       efree(&passwd);
-      return(_("Remote host is not using the good version of the Nessus communication protocol (1.2) or is tcpwrapped"));
+      return(_("Unable to establish a connection to the remote host using the specified protocol version!"));
     }
 
   if(comm_get_plugins(context))
   {
-#ifdef NESSUS_ON_SSL
     close_stream_connection(context->socket);
     efree(&pem_pass);
-#else
-    shutdown(context->socket, 2);
-#endif
     context->socket = -1;
     efree(&passwd);
     return(_("Login failed"));
@@ -683,534 +624,412 @@ Please launch nessusclient-mkrand(1) first !"));
 #endif
 
   efree(&passwd);
-#ifdef NESSUS_ON_SSL
   efree(&pem_pass);
-#endif
   return(NULL);
 }
 
 
-void 
-display_help 
-  (char *pname)
-{
-  
- printf("%s, version %s\n", pname, NESSUS_FULL_VERSION);
-#ifdef USE_AF_INET
- printf(_("\nCommon options :\n %s [-vnh] [-c .rcfile] [-V] [-T <format>]"),pname);
- printf(_("\nBatch-mode scan:\n %s -q [-pPS] <host> <port> <user> <pass> <targets-file> <result-file>"),pname);
- printf(_("\nList sessions  :\n %s -s -q <host> <port> <user> <pass> "),pname);
- printf(_("\nRestore session:\n %s -R <sessionid> -q <host> <port> <user> <pass> <result-file> "),pname);
-#else /* AF_UNIX */
- printf(_("\nBatch-mode scan:\n %s -q [-pPS] <user> <pass> <targets-file> <result-file>"),pname);
- printf(_("\nList sessions  :\n %s -s -q <user> <pass> "),pname);
- printf(_("\nRestore session:\n %s -R <sessionid> -q <user> <pass> <result-file> "),pname);
-#endif
- printf(_("\nReport conversion :\n %s -i in.nbe -o out.[html|xml|nbe]\n\n"), pname);
- printf(_("General options :\n"));
- printf(_("\t-v : shows version number\n"));
- printf(_("\t-h : shows this help\n")); 
- printf(_("\t-n : No pixmaps\n"));
- printf(_("\t-T : Output format: 'nbe', 'html', 'html_graph', 'text', 'xml',\n"));
- printf("\t    'old-xml' or 'tex'\n");
- printf(_("\t-V : make the batch mode display status messages\n"
-          "\t    to the screen.\n"));
- printf(_("\t-x : override SSL \"paranoia\" question preventing OpenVAS-Client from\n"
-          "\t    checking certificates.\n\n"));
-
- printf(_("The batch mode (-q) arguments are :\n"));
-#ifdef USE_AF_INET
- printf(_("\thost     : openvasd host\n"));
- printf(_("\tport     : openvasd host port\n"));
-#endif
- printf(_("\tuser     : user name\n"));
- printf(_("\tpass     : password\n"));
- printf(_("\ttargets  : file containing the list of targets\n"));
- printf(_("\tresult   : name of the file where \n\t\t   OpenVAS-Client will store the results\n"));
- printf(_("\t-p       : obtain list of plugins installed on the server.\n"));
- printf(_("\t-P       : obtain list of server and plugin preferences.\n"));
- printf(_("\t-S       : issue SQL output for -p and -P (experimental).\n"));
-}
- 
-	
-
-
-
-
- 
 int main(int argc, char * argv[])
 {
-  int i, xac;
-  char *myself, **xav;
-  int gui = 1;
-  char * output_type = NULL;
-  int opt_m = 0;
-  int list_sessions = 0;
-  int list_plugins = 0;
-  int list_prefs  = 0;
-  int sqlize_output = 0;
-  int restore_session = 0;
-#ifdef ENABLE_SAVE_TESTS
-  char * session_id = NULL;
-#endif
   char * arg = NULL;
-  int opt_V= 0;
-  int opt_i= 0;
-  int opt_o= 0;
-  char * inf = NULL, *outf = NULL;
+  gchar *myself = NULL;
 
   /* Setup I18N. */
   i18n_init();
 
-
-  
-  if ((myself = strrchr (*argv, '/')) == 0
-#ifdef _WIN32
-      && (myself = strrchr (*argv, '\\')) == 0
-#endif
-      ) myself = *argv ;
-  else
-    myself ++ ;
-
   MainDialog = NULL;
 #ifdef USE_GTK
-  F_quiet_mode = 0;
-  F_show_pixmaps = 1;
+  quiet_mode = FALSE;
+  show_pixmaps = TRUE;
 #endif
 
-  /* provide a extra acrgc/argv vector for later use */
-  xac = 1;
-  xav = append_argv (0, myself);
-#if 0
-  pty_logger ((void(*)(const char*, ...))printf);
+  /* Options for command line parsing */
+  static gboolean make_config_file = FALSE;  
+  static gboolean display_version = FALSE;
+  static gboolean verbose = FALSE;
+#ifdef USE_GTK  
+  static gboolean no_pixmap = FALSE;
 #endif
-  for (;;) {
-    int option_index = 0;
-    static struct option long_options[] =
-    {
-      {"help",                 no_argument, 0, 'h'},
-      {"version",              no_argument, 0, 'v'},
-      /*
-       * Key options should be removed! (MA 2001-11-21)
-       */
+  static gboolean batch_mode = FALSE;
+  static gboolean list_plugins = FALSE;
+  static gboolean list_prefs = FALSE;
+  static gchar *in_report = NULL;
+  static gchar *out_report = NULL;
+  static gchar *config_file = NULL;
+  static gchar *output_type = NULL;
+  static gboolean sqlize_output = FALSE;
+  static gboolean list_sessions = FALSE;
+  static gboolean restore_session = FALSE;
+  static gchar **remaining_options = NULL;
+  guint remaining_options_count = 0;
+  GError *error = NULL;
+  GOptionContext *option_context;
+  gchar *session_id = NULL;
+  static GOptionEntry entries[] = 
+  {
+    { "version", 'v', 0, G_OPTION_ARG_NONE, &display_version, N_("Display version information"), NULL },
 #ifdef USE_GTK
-      {"open-report",    required_argument, 0, 'r'},   
-      {"no-pixmap",            no_argument, 0, 'n'},
+    { "no-pixmap", 'n', 0, G_OPTION_ARG_NONE, &no_pixmap, N_("No pixmaps"), NULL },
 #endif
-      {"batch-mode",           no_argument, 0, 'q'},
-      {"make-config-file",     no_argument, 0, 'm'},
-      {"config-file", 	 required_argument, 0, 'c'},
-      {"output-type",	 required_argument, 0, 'T'},
-      {"verbose",		no_argument,0, 'V'},
-      {"list-plugins",		no_argument,0, 'p'},
-      {"list-prefs",		no_argument,0, 'P'},
-      {"in-report",	required_argument, 0, 'i'},
-      {"out-report",	required_argument, 0, 'o'},
-      {"dont-check-ssl-cert", no_argument,	0,  'x'},
-      {"sqlize-output", no_argument, 0, 'S'},
-#ifdef ENABLE_SAVE_TESTS      
-      {"list-sessions",        no_argument, 0, 's'},
-      {"restore-session",required_argument, 0, 'R'},
-#endif      
-      {0, 0, 0, 0}
-    };
+    { "batch-mode", 'q', 0, G_OPTION_ARG_NONE, &batch_mode, N_("Batch-mode scan"), N_("<host> <port> <user> <pass> <targets-file> <result-file>") },
+    { "make-config-file", 'm', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &make_config_file, "", NULL },
+    { "config-file", 'c', 0, G_OPTION_ARG_FILENAME, &config_file, N_("Configuration file"), N_("<.rcfile>") },
+    { "output-type", 'T', 0, G_OPTION_ARG_STRING, &output_type, N_("Output format"), N_("[nbe|html|html_graph|text|xml|tex]") },
+    { "verbose", 'V', 0, G_OPTION_ARG_NONE, &verbose, N_("Display status messages in batch mode"), NULL },
+    { "list-plugins", 'p', 0, G_OPTION_ARG_NONE, &list_plugins, N_("Obtain list of plugins installed on the server"), NULL },
+    { "list-prefs", 'P', 0, G_OPTION_ARG_NONE, &list_prefs, N_("Obtain list of server and plugin preferences"), NULL },
+    { "in-report", 'i', 0, G_OPTION_ARG_FILENAME, &in_report, N_("Input file (report conversion)"), N_("<in.nbe>") },
+    { "out-report", 'o', 0, G_OPTION_ARG_FILENAME, &out_report, N_("Output file (report conversion)"), N_("<out.[html|xml|nbe]>") },
+    { "dont-check-ssl-cert", 'x', 0, G_OPTION_ARG_NONE, &dont_check_ssl_cert, N_("Override SSL \"paranoia\" question preventing OpenVAS-Client from checking certificates"), NULL },
+    { "sqlize-output", 'S', 0, G_OPTION_ARG_NONE, &sqlize_output, N_("Issue SQL output for -p and -P (experimental)"), NULL },
+    { "list-sessions", 's', 0, G_OPTION_ARG_NONE, &list_sessions, N_("List sessions"), N_("<host> <port> <user> <pass>") },
+    { "restore-session", 'R', 0, G_OPTION_ARG_NONE, &restore_session, N_("Restore session"), N_("<sessionid> <host> <port> <user> <pass> <result-file>") },
+    { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &remaining_options, NULL, NULL },
+    { NULL }
+  };
 
-    if ((i = getopt_long 
-	 (argc, argv, "Ppc:T:Vvhqn?r:01sR:Smi:o:x", long_options, &option_index)) == EOF)
-      break;
-     else
-      
-    switch(i) {
-    case 'x' :
-    	DontCheckServerCert++;
-	break;
-     case 'i': 
-     	opt_i++;
-	if(!optarg)
-	{ 
-	 display_help("nessus");
-	 exit(1);
-	}
-	inf = estrdup(optarg);
-	break;
-   case 'o':
-   	opt_o++;
-   	if(!optarg)
-	{
-	 display_help("nessus");
-	 exit(1);
-	}
-	outf = estrdup(optarg);
-	break;
-     case 'T' :
-       if(!optarg)
-       {
-        display_help("nessus");
-	exit (1);
-       }
-        if(optarg[0]=='=')inc_optind(); /* no optind++ on Win32 -- jordan */
-	output_type = optarg;
-	break;    
-     case 'c' :
-       if(!optarg)
-       {
-        display_help("nessus");
-	exit (1);
-       }
-       else Alt_rcfile = estrdup(optarg);
-       break;
+  option_context = g_option_context_new(_("- client for the OpenVAS security scanner"));
+  g_option_context_add_main_entries(option_context, entries, NULL);
 #ifdef USE_GTK
-    case 'n' : 
-      F_show_pixmaps = 0;
-      break;
+  g_option_context_add_group(option_context, gtk_get_option_group (TRUE));
+#endif
+  if (!g_option_context_parse(option_context, &argc, &argv, &error))
+  {
+    g_print("%s\n\n", error->message);
+    exit (0);
+  }
 
-    case 'r' : 
-      xac ++ ;
-      xav = append_argv (xav, optarg) ;
-      break;
-#endif    	
+  myself = g_get_prgname();
 
-    case 'V':
-      	 opt_V++;
-	 break;
-    case 'v' :
-    	printf("nessus (%s) %s for %s\n\n(C) 1998 - 2003 Renaud Deraison <deraison@nessus.org>\n", 
-    			PROGNAME,NESSUS_VERSION, NESS_OS_NAME);
-#ifdef NESSUS_ON_SSL
-	printf(_("\tSSL used for client - server communication\n"));
-#else
-	printf(_("\tclient - server communication is done in PLAIN TEXT\n"));
-#endif					
-	printf ("\n");
-    	exit(0);
-    	break;
+  g_option_context_free(option_context);
 
-    case 'm' :
-      opt_m ++;
-      break;
-    case 'q' :
-      gui = 0; 
-      F_quiet_mode ++ ;
-      break;
-    case 'P':
-     list_prefs++;
+  if (remaining_options != NULL)
+    while (remaining_options[remaining_options_count] != NULL)
+      remaining_options_count++;
+
+  if (config_file != NULL)
+    Alt_rcfile = g_strdup(config_file);
+
+#ifdef USE_GTK
+  if (no_pixmap)
+      show_pixmaps = FALSE;
+#endif
+
+  if (display_version)
+  {
+    printf(_("OpenVAS-Client (%s) %s for %s\n\n"), PROGNAME, NESSUS_VERSION, NESS_OS_NAME);
+    printf(_("NessusClient origin: (C) 1998 - 2003 Renaud Deraison <deraison@nessus.org>\n"));
+    printf(_("New code since OpenVAS-Client: (C) 2007, 2008 Intevation GmbH\n"));
+    printf ("\n");
+    exit(0);
+  }
+
+  if (batch_mode)
+  {
+    quiet_mode = TRUE;
+  }
+
+  if (list_prefs)
+  {
      ListOnly = 1;
-     break;
-    case 'p' :
-     list_plugins ++;
-      break;
-      
-     case 'S': 
-    	sqlize_output++;
-	break;  
-      
+  }
+
 #ifdef ENABLE_SAVE_TESTS
-    case 's' :
-      list_sessions ++;
-      break;
-   
-    case 'R' :
-      restore_session ++;
-      if(optarg)session_id = strdup(optarg);
-      else {
-      	display_help(myself);
-	exit(1);
-	}
-       break;	
-#endif
-    default:
-      display_help (myself);
-      exit (0);
+
+  if (restore_session)
+  {
+    if(remaining_options != NULL)
+      // TODO: Is remaining_options[0] enough? restore_session seems to completely ignore session_id anyway.
+      session_id = g_strdup(remaining_options[0]);
+    else
+    {
+      printf(_("The session ID is required to restore a session.\n"));
+      printf(_("Please use %s --help for more information.\n"), myself);
+      exit(1);
     }
   }
+#endif
+  F_quiet_mode = quiet_mode;
+  F_show_pixmaps = show_pixmaps;
 
   /* Initialize global context */
   context_init(&Global, NULL);
   Context = Global;
 
- if(opt_i || opt_o)
- {
-  int be;
-  if(!(opt_i && opt_o))
-   {
-    display_help("nessus");
-    exit(1);
-   }
-  F_quiet_mode = 1;
-  be = backend_import_report(inf);
-  if(be >= 0)
+  if((in_report != NULL) || (out_report != NULL))
   {
-   char * type;
-   if(!output_type)
+    int be;
+    if(!((in_report != NULL) && (out_report != NULL)))
     {
-     type = strrchr(outf, '.');
-     if(type != NULL)type++;
-     else type = "nbe";
+      printf(_("You need to specify an input file as well as an output file for report conversion.\n"));
+      printf(_("Please use %s --help for more information.\n"), myself);
+      exit(1);
     }
-   else {
-    type = output_type;
+    F_quiet_mode = TRUE;
+    be = backend_import_report(in_report);
+    if(be >= 0)
+    {
+      char * type;
+      if(!output_type)
+      {
+        type = strrchr(out_report, '.');
+        if(type != NULL)
+          type++;
+        else
+          type = "nbe";
+      }
+      else
+      {
+        type = output_type;
+      }
+      if(!strcmp(type, "tex") || !strcmp(type, "latex"))
+        arglist_to_latex(backend_convert(be), out_report);
+      else if(!strcmp(type, "txt") || !strcmp(type, "text"))
+        arglist_to_text(backend_convert(be), out_report);
+      else if(!strcmp(type, "html"))
+        arglist_to_html(backend_convert(be), out_report);
+      else if(!strcmp(type, "html_pie") || !strcmp(type, "html_graph"))
+        arglist_to_html_graph(backend_convert(be), out_report);
+      else if(!strcmp(type, "nbe"))
+        backend_to_nbe(be, out_report);
+      else if(!strcmp(type, "xml"))
+        backend_to_xml_ng(be, out_report); 
+      else
+      {
+        fprintf(stderr, _("Unsupported report type '%s'\n"), type);
+        exit(1);
+      }
+      backend_close(be);
+      exit(0);
     }
-   if(!strcmp(type, "tex") ||
-      !strcmp(type, "latex"))
-      	arglist_to_latex(backend_convert(be), outf);
-   else if(!strcmp(type, "txt") ||
-   	   !strcmp(type, "text"))
-	arglist_to_text(backend_convert(be), outf);
-   else if(!strcmp(type, "html"))
-   	arglist_to_html(backend_convert(be), outf);
-   else if(!strcmp(type, "html_pie") || !strcmp(type, "html_graph"))
-   	arglist_to_html_graph(backend_convert(be), outf);
-   else if(!strcmp(type, "nbe"))
-   	backend_to_nbe(be, outf);
-   else if(!strcmp(type, "old-xml"))
-   	arglist_to_xml(backend_convert(be), outf);
-   else if(!strcmp(type, "xml"))
-   	backend_to_xml_ng(be, outf); 
-   else
-   	{
-	 fprintf(stderr, _("Unsupported report type '%s'\n"), type);
-	 exit(1);
-	 }
-  backend_close(be);
-  exit(0);
+    else
+    {
+      fprintf(stderr, _("Could not import '%s' - is it a .nbe file?\n"), 
+              in_report);
+    }
+    exit(0);
+  }
+
+  if(make_config_file && !quiet_mode)
+  {
+    printf(_("The option -make_config_file can only be used in batch mode.\n"));
+    printf(_("Please use %s --help for more information.\n"), myself);
+    exit(1);
   }
-  else
-  {
-   fprintf(stderr, _("Could not import '%s' - is it a .nbe file?\n"),
-   		inf);		
-  }
-  exit(0);
- }
 
- if(!gui)F_quiet_mode = 1;
- 
- if(opt_m && !F_quiet_mode)
- {
-  display_help(myself);
-  exit(1);
- }
-	
-#ifdef USE_AF_INET
 #define BATCH_USAGE "-q host port user pass"
-#else
-#define BATCH_USAGE "-q user pass"
-#endif
+#define BATCH_ARGC 4
 	
 #ifdef ENABLE_SAVE_TESTS
- if(list_sessions && (argc<=optind) && !F_quiet_mode)
- {
-  fprintf(stderr, _("list-sessions requires %s\n"), BATCH_USAGE);
-  exit(1);
- }
- 
- if(restore_session && (argc<=optind) && !F_quiet_mode)
- {
-  fprintf(stderr, _("restore-session requires -q %s result\n"), BATCH_USAGE);
-  exit(1);
- }
- 
- if(restore_session && list_sessions)
- {
-  fprintf(stderr, _("--restore-session and --list-sessions are mutually exclusive\n"));
-  exit(1);
- }
+  if(list_sessions && (remaining_options_count < BATCH_ARGC) && !quiet_mode)
+  {
+    fprintf(stderr, _("list-sessions requires %s\n"), BATCH_USAGE);
+    exit(1);
+  }
+
+  if(restore_session && (remaining_options_count < BATCH_ARGC) && !quiet_mode)
+  {
+    fprintf(stderr, _("restore-session requires -q %s result\n"), BATCH_USAGE);
+    exit(1);
+  }
+
+  if(restore_session && list_sessions)
+  {
+    fprintf(stderr, _("--restore-session and --list-sessions are mutually exclusive\n"));
+    exit(1);
+  }
 #endif
 
 
- if(argc>optind || F_quiet_mode)
-     {
-      signal(SIGINT, sighand_exit);
-      signal(SIGQUIT, sighand_exit);
-      signal(SIGKILL, sighand_exit);
-      signal(SIGTERM, sighand_exit);
-      
-      F_quiet_mode = 1;
-     }
-#ifdef USE_GTK     
+  if(remaining_options_count >= BATCH_ARGC || quiet_mode)
+  {
+    signal(SIGINT, sighand_exit);
+    signal(SIGQUIT, sighand_exit);
+    signal(SIGKILL, sighand_exit);
+    signal(SIGTERM, sighand_exit);
+
+    F_quiet_mode = TRUE;
+  }
+#ifdef USE_GTK
   else
-    {
-      gtk_init(&argc, &argv);
-     }
+  {
+    gtk_init(&argc, &argv);
+  }
 #endif
 
   /* system environment set up */
-  if(!opt_m)
+  if(!make_config_file)
   {
     if (preferences_init(Global))
-    exit (2);
+      exit (2);
   }
   else
     Global->prefs = emalloc(sizeof(struct arglist));
 
 #ifdef USE_GTK
-  if(!F_quiet_mode)
+  if(!quiet_mode)
     context_collect(Global);
 #endif /* USE_GTK */
 
-  if(opt_V && !F_quiet_mode)
+  if(verbose && !quiet_mode)
   {
-	  fprintf(stderr, _("Verbose mode can only be used in batch mode\n"));
-	  exit(1);
+    fprintf(stderr, _("Verbose mode can only be used in batch mode\n"));
+    exit(1);
   }
   
   /* do we run in batchmode ? */
-  if (argc > optind || F_quiet_mode) {
+  if (remaining_options_count >= BATCH_ARGC || quiet_mode)
+  {
     struct cli_args * cli;
-     
-    F_quiet_mode = 1;
-    
-    cli = cli_args_new();
-    cli_args_verbose(cli, opt_V);
-    
-    /* with, or without ENABLE_CRYPTO_LAYER */
-#   define NUM_ARGS 6
 
-#ifndef USE_AF_INET
-#   undef  NUM_ARGS
-#   define NUM_ARGS 4
-#endif
- 
+    F_quiet_mode = TRUE;
+
+    cli = cli_args_new();
+    cli_args_verbose(cli, verbose);
+
+    /* with, or without ENABLE_CRYPTO_LAYER */
+#define NUM_ARGS 6
 
 #ifndef ENABLE_SAVE_TESTS
-    if (argc - optind != NUM_ARGS) {
-      if(!((argc - optind == NUM_ARGS - 2) && opt_m))
+
+    if (remaining_options_count != NUM_ARGS)
+    {
+      if(!((remaining_options_count == NUM_ARGS - 2) && make_config_file))
       {
-       display_help(myself);
-       exit(0);
-       }
+        printf(_("Batch mode requires login information.\n"));
+        printf(_("Please use %s --help for more information.\n"), myself);
+        exit(0);
+      }
     }
 #else
- if(list_sessions || opt_m || list_plugins || list_prefs)
-  {
-  if (argc - optind != NUM_ARGS - 2) {
-      fprintf(stderr, "%s" BATCH_USAGE "\n", _("list-sessions only requires "));
-      exit(1);
+    if(list_sessions)
+    {
+      if (remaining_options_count != NUM_ARGS - 2)
+      {
+        fprintf(stderr, "%s" BATCH_USAGE "\n",
+                _("list-sessions only requires "));
+        exit(1);
+      }
     }
-  }
-  else if(restore_session)
-  {
-    if (argc - optind != NUM_ARGS - 1) {
-      fprintf(stderr, "%s" BATCH_USAGE " <result-file>\n", _("restore-session only requires "));
-      exit(1);
+    else if(restore_session)
+    {
+      if (remaining_options_count != NUM_ARGS - 1)
+      {
+        fprintf(stderr, "%s" BATCH_USAGE " <result-file>\n",
+                _("restore-session only requires "));
+        exit(1);
+      }
     }
-  }
-  else
-  if (argc - optind != NUM_ARGS) {
-      display_help(myself);
+    else if (remaining_options_count != NUM_ARGS) 
+    {
+      printf(_("Batch mode requires login information.\n"));
+      printf(_("Please use %s --help for more information.\n"), myself);
       exit(0);
     }
 
-   
-#endif    
-    
-
-    /* next arguments: SERVER PORT */
-#ifdef USE_AF_INET
-    cli_args_server(cli, argv[inc_optind()]);
-    cli_args_port(cli, atoi(argv[inc_optind()]));
-#else
-    cli_args_server(cli, "localhost");
-    cli_args_port(cli, 0);
 #endif
 
+    /* next arguments: SERVER PORT */
+    cli_args_server(cli, remaining_options[0]);
+    cli_args_port(cli, atoi(remaining_options[1]));
+
     /* next argument: LOGIN */
-    arg = argv[inc_optind()];
+    arg = remaining_options[2];
     cli_args_login(cli, arg);
     bzero(arg, strlen(arg));
 
-   
     /* next argument: PASSWORD */
-    arg = argv[inc_optind()];
+    arg = remaining_options[3];
     cli_args_password(cli, arg);
     bzero(arg, strlen(arg));
 
     if(list_prefs)
     {
-     if(cli_connect_to_nessusd(cli) < 0)
-     {
-      fprintf(stderr, _("Could not connect to openvasd\n"));
-      exit(1);
-     }
-    if(sqlize_output)
-    	cli_sql_dump_prefs(cli);
-    else
-    	cli_dump_prefs(cli);
-    cli_close_connection(cli);
-    exit(0);
-    }
-    if(list_plugins)
-    {
-     if(cli_connect_to_nessusd(cli) < 0)
+      if(cli_connect_to_nessusd(cli) < 0)
       {
-       fprintf(stderr, _("Could not connect to openvasd\n"));
-       exit(1);
-       }
+        fprintf(stderr, _("Could not connect to openvasd\n"));
+        exit(1);
+      }
       if(sqlize_output)
-        cli_sql_dump_plugins(cli);
-      else 
-      	cli_dump_plugins(cli);
-	
+        cli_sql_dump_prefs(cli);
+      else
+        cli_dump_prefs(cli);
       cli_close_connection(cli);
       exit(0);
     }
-    
-    
 
-   if(!opt_m)
-   {
-   if(restore_session)
-   {
-     cli_args_results(cli,  argv[inc_optind()]);
-   }
-   else
-    if(!list_sessions)
-     {
-      char * t = argv[inc_optind()];
-      if(t)cli_args_target(cli, t);
-      else {
-	      fprintf(stderr, _("Missing parameter\n"));
-	      display_help(myself);
+    if(list_plugins)
+    {
+      if(cli_connect_to_nessusd(cli) < 0)
+      {
+        fprintf(stderr, _("Could not connect to openvasd\n"));
+        exit(1);
       }
-      t = argv[inc_optind()];
-      if(t) cli_args_results(cli,  t);
-      else {
-	      fprintf(stderr, _("Missing parameter\n"));
-	      display_help(myself);
+      if(sqlize_output)
+        cli_sql_dump_plugins(cli);
+      else 
+        cli_dump_plugins(cli);
+
+      cli_close_connection(cli);
+      exit(0);
+    }
+
+    if(!make_config_file)
+    {
+      if(restore_session)
+      {
+        cli_args_results(cli, remaining_options[4]);
       }
-     }
-   }
-   
+      else
+      {
+        if(!list_sessions)
+        {
+          char * t = remaining_options[4];
+          if(t)
+            cli_args_target(cli, t);
+          else
+          {
+            fprintf(stderr, _("Missing parameter\n"));
+          }
+          t = remaining_options[5];
+          if(t)
+            cli_args_results(cli,  t);
+          else
+          {
+            fprintf(stderr, _("Missing parameter\n"));
+          }
+        }
+      }
+    }
+
     cli_args_output(cli, output_type);
-    
-    
+
     /* login now */
-    if((cli_connect_to_nessusd(cli))<0)
-	nessus_exit(1);
+    if((cli_connect_to_nessusd(cli)) < 0)
+      nessus_exit(1);
 #ifdef ENABLE_SAVE_TESTS
-    if(list_sessions){
-    	cli_list_sessions(cli);
-#ifdef NESSUS_ON_SSL
-	close_stream_connection(Context->socket);
-#else
-	shutdown(Context->socket ,2);
-	closesocket(Context->socket);
+    if(list_sessions)
+    {
+      cli_list_sessions(cli);
+      close_stream_connection(Context->socket);
+      Context->socket = -1;
+      nessus_exit(0);
+    }
+    else if(restore_session)
+    {
+      cli_restore_session(cli, session_id);
+    }
+    else	
 #endif
-	Context->socket = -1;
-	nessus_exit(0);
-	}
-    else if(restore_session) {
-    	cli_restore_session(cli, session_id);
-	}
-   else	
-#endif    	
-    if(opt_m){
-    	if(!preferences_generate_new_file(Global, NULL))
-	 printf(_("A new openvasrc file has been saved\n"));
-	}
+    if(make_config_file)
+    {
+      if(!preferences_generate_new_file(Global, NULL))
+        printf(_("A new openvasrc file has been saved\n"));
+    }
     else
-     {
-     cli_test_network(cli);
-     cli_report(cli);
+    {
+      cli_test_network(cli);
+      cli_report(cli);
     }
     /* end, exit */
     nessus_exit(0);
@@ -1248,10 +1067,11 @@ int main(int argc, char * argv[])
   return 0; /* make the compiler happy */
 
 #else
-  printf(_("\nOoops ...\n\
-  This nessus version has no gui support.  You need to give nessus the\n\
-  arguments SERVER PORT LOGIN TRG RESULT as explained in more detail\n\
-  using the --help option.\n"));
+  printf(_("\n\
+  This version of OpenVAS-Client was compiled without gui support\n\
+  and can only be run in batch mode.\n\
+  Help on running OpenVAS-Client in batch mode is available using\n\
+  the --help option and in the OpenVAS documentation.\n"));
   exit (1);
 #endif
 }
