@@ -392,7 +392,48 @@ static int exec_htmldoc(char ** argv)
  return WEXITSTATUS(ret);
 }
 
+char**  append_argv(char **argv, char   *opt)
+{
+  int argc, n ;
   
+  /* special case */
+  if (opt == 0) {
+    if (argv == 0) 
+      (argv = emalloc(sizeof (char*))) [0] = 0 ;
+    return argv ;
+  }
+  
+  if (argv == 0) {
+    argc = 1 ;
+    argv = emalloc(2 * sizeof (char*));
+  } else {
+
+    /* calculate dim (argv) - 1 */
+    argc = 0 ;
+    while (argv [argc ++] != 0)
+      ;
+
+    /* append one more item */
+    n = (++ argc) * sizeof (char*) ;
+    argv = erealloc(argv, n) ;
+    argv [-- argc] = 0 ;
+  }
+
+  /* append one duplicated item before the NULL entry */
+  argv [-- argc] = estrdup(opt);
+  return argv ;
+}
+
+void    destroy_argv(char **argv)
+{
+  int argc ;
+  if (argv == 0)
+    return ;
+  for (argc = 0; argv [argc] != 0; argc ++)
+    efree (&argv [argc]) ;
+  efree (&argv);
+}
+
 
 int
 arglist_to_pdf(struct context * context, int be, char * filename)
@@ -946,3 +987,5 @@ print_appendix(FILE *file, GHashTable *hash)
   g_hash_table_foreach(hash, print_plugin_information, file);
 }
 
+
+
