@@ -119,18 +119,10 @@ plugin_cache_get_filename(struct context *context)
   }
   else
   {
-    if (Alt_rcfile)
-      /* if an alternate rc file was given on the command line, we do
-       * not know where to store the plugin cache, so we don't cache the
-       * plugin descriptions at all */
-      filename = NULL;
-    else
-    {
-      char *home = prefs_get_nessushome();
+    char *home = prefs_get_nessushome();
 
-      filename = emalloc(strlen(home) + strlen("/.openvas_plugin_cache") + 1);
-      sprintf(filename, "%s/.openvas_plugin_cache", home);
-    }
+    filename = emalloc(strlen(home) + strlen("/.openvas_plugin_cache") + 1);
+    sprintf(filename, "%s/.openvas_plugin_cache", home);
   }
 
   return filename;
@@ -336,13 +328,6 @@ plugin_cache_write(struct context * context, const char * server_md5sum)
   int failure = 0;
 
   filename = plugin_cache_get_filename(context);
-  if (!filename)
-  {
-    /* the only failure cause currently is that the user has specified a
-     * different nessusrc file.  In that case no caching takes place.
-     */
-    return 1;
-  }
 
   file = fopen(filename, "w");
   if (!file)
