@@ -161,9 +161,7 @@ preferences_new(context)
   if(context->type != CONTEXT_TASK && context->type != CONTEXT_REPORT)
   {
     fprintf(f, _("# OpenVAS-Client Preferences File\n\n"));
-#ifdef NESSUS_ON_SSL
     fprintf(f, "trusted_ca = cacert.pem\n");
-#endif /* NESSUS_ON_SSL */
     fprintf(f, "begin(SCANNER_SET)\n");
     fprintf(f, "10180 = yes\n");
     fprintf(f, "10278 = no\n");
@@ -370,7 +368,8 @@ prefs_buffer_parse(buffer, arglist, keep_order)
     if(!strcmp(t, "no"))
       val = 0;
 
-    if(!strcmp(opt, "paranoia_level") || !strcmp(opt, "nessusd_port") || !strcmp(opt, "sort_order"))
+    if(!strcmp(opt, "paranoia_level") || !strcmp(opt, "nessusd_port") ||
+        !strcmp(opt, "sort_order") || !strcmp(opt, "protocol_version"))
     {
       arg_add(arglist, opt, ARG_INT, sizeof(int), (void *)atoi(t));
     }
@@ -534,8 +533,8 @@ preferences_save_as(context, filename)
   {
     if((int)t->type == ARG_INT)
     {
-      if(!strcmp(t->name, "paranoia_level")
-	  || !strcmp(t->name, "nessusd_port") || !strcmp(t->name, "sort_order"))
+      if(!strcmp(t->name, "paranoia_level") || !strcmp(t->name, "nessusd_port")
+          || !strcmp(t->name, "sort_order") || !strcmp(t->name, "protocol_version"))
 	fprintf(fd, "%s = %d\n", t->name, (int)t->value);
       else
 	fprintf(fd, "%s = %s\n", t->name, t->value ? "yes" : "no");
@@ -660,12 +659,8 @@ prefs_get_default(context, name)
     return get_username();
   else if(!strcmp(name, "nessusd_port"))
     return (void *)NESIANA_PORT;
-#ifdef NESSUS_ON_SSL
-  else if(!strcmp(name, "use_ssl"))
-    return (void *)1;
   else if(!strcmp(name, "ssl_version"))
     return SSL_VER_DEF_NAME;
-#endif /* NESSUS_ON_SSL */
   else if(!strcmp(name, "nessus_dir"))
   {
     static char *nessus_dir;
@@ -719,6 +714,8 @@ prefs_get_default(context, name)
     return (void *)1;
   else if(!strcmp(name, "report_plugin_details_in_pdf"))
     return (void *)1;
+  else if(!strcmp(name, "show_nvt_name_and_oid"))
+    return (void *)1;
   else
     return NULL;
 }
