@@ -102,7 +102,7 @@ show_users_manual(menuitem, ctrls)
 #endif
 #else
   char * dir = g_win32_get_package_installation_subdirectory(NULL, NULL,
-                 "share\\doc\\OpenVAS");
+                 "share\\doc\\openvas-manual");
 #endif /* CYGWIN */
 
   /* the pdf file is covered by gettext to allow
@@ -779,7 +779,7 @@ prefs_dialog_setup(context)
   icon = gtk_image_new();
   gtk_widget_show(icon);
   gtk_box_pack_start(GTK_BOX(hbox), icon, FALSE, TRUE, 0);
-  arg_add_value(ctrls, "CONNECT_ENCRYPTED_IMAGE", ARG_PTR, -1, icon);
+  arg_add_value(ctrls, "CONNECT_IMAGE", ARG_PTR, -1, icon);
 
 /*
  * Final
