@@ -33,10 +33,6 @@
 #include "prefs_help.h"
 #include "globals.h"
 
-#ifndef USE_AF_INET
-#undef ENABLE_CRYPTO_LAYER
-#endif
-
 struct auth_fileselect {
   struct auth_dialog *auth;
   GtkWidget *box;
@@ -51,17 +47,12 @@ struct auth_dialog {
   GtkWidget *port;
   GtkWidget *username;
   GtkWidget *password;
-#ifdef NESSUS_ON_SSL
-  GtkWidget *use_ssl;
   GtkWidget *use_client_cert;
   struct auth_fileselect *trusted_ca;
   struct auth_fileselect *cert_file;
   struct auth_fileselect *key_file;
-#endif /* NESSUS_ON_SSL */
 };
 
-
-#ifdef USE_AF_INET
 const gchar *
 prefs_dialog_auth_hostname(auth)
   struct auth_dialog *auth;
@@ -101,7 +92,6 @@ prefs_dialog_auth_defaultport_clicked(button, auth)
       (int)prefs_get_default(auth->context, "nessusd_port"));
 }
 
-#ifdef NESSUS_ON_SSL
 void
 prefs_dialog_auth_fileselect_popup(button, auth_fileselect)
   GtkButton *button;
@@ -129,8 +119,6 @@ prefs_dialog_auth_fileselect_popup(button, auth_fileselect)
   }
   gtk_widget_destroy(dialog);
 }
-#endif /* NESSUS_ON_SSL */
-#endif /* USE_AF_INET */
 
 const gchar *
 prefs_dialog_auth_username(auth)
@@ -154,11 +142,8 @@ prefs_dialog_auth_password(auth)
   const gchar *text;
   text = gtk_entry_get_text(GTK_ENTRY(auth->password));
   if(!(text && (strlen(text)
-#ifdef NESSUS_ON_SSL
-      || (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(auth->use_ssl)) &&
-	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(auth->use_client_cert)))
-#endif /* NESSUS_ON_SSL */
-      )))
+      || gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(auth->use_client_cert)))
+      ))
   {
     gtk_widget_grab_focus(auth->password);
     show_warning(_("You must enter a valid password"));
@@ -167,7 +152,6 @@ prefs_dialog_auth_password(auth)
   return text;
 }
 
-#ifdef NESSUS_ON_SSL
 const gchar *
 prefs_dialog_auth_trusted_ca(auth, context)
   struct auth_dialog *auth;
@@ -215,7 +199,6 @@ prefs_dialog_auth_key_file(auth)
   }
   return text;
 }
-#endif /* NESSUS_ON_SSL */
 
 
 char *
@@ -312,7 +295,6 @@ prefs_dialog_auth_vbox(text, content)
   return vbox;
 }
 
-#ifdef NESSUS_ON_SSL
 struct auth_fileselect *
 prefs_dialog_auth_fileselect(auth, text, pref_name, box)
   struct auth_dialog *auth;
@@ -356,8 +338,7 @@ prefs_dialog_auth_update(widget, auth)
   GtkWidget *widget;
   struct auth_dialog *auth;
 {
-  gboolean use_ssl = gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON(auth->use_ssl));
+  gboolean use_ssl = TRUE;
   gboolean use_client_cert = gtk_toggle_button_get_active(
       GTK_TOGGLE_BUTTON(auth->use_client_cert));
 
@@ -366,7 +347,6 @@ prefs_dialog_auth_update(widget, auth)
   gtk_widget_set_sensitive(auth->cert_file->box, use_ssl && use_client_cert);
   gtk_widget_set_sensitive(auth->key_file->box, use_ssl && use_client_cert);
 }
-#endif /* NESSUS_ON_SSL */
 
 void
 prefs_dialog_auth_create_dialog(context, auth)
@@ -380,12 +360,8 @@ prefs_dialog_auth_create_dialog(context, auth)
   GtkWidget *hbox;
   GtkWidget *hbox2;
   GtkWidget *button;
-#ifdef USE_AF_INET
   GtkObject *port_adj;
-# ifdef NESSUS_ON_SSL
   GtkWidget *vbox;
-# endif /* NESSUS_ON_SSL */
-#endif /* USE_AF_INET */
 
   auth->context = context;
 
@@ -405,8 +381,6 @@ prefs_dialog_auth_create_dialog(context, auth)
   gtk_container_set_border_width(GTK_CONTAINER(dialog_vbox), 4);
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox), dialog_vbox);
 
-
-#ifdef USE_AF_INET
   frame = gtk_frame_new(_("OpenVAS Server"));
   gtk_widget_show(frame);
   gtk_box_pack_start_defaults(GTK_BOX(dialog_vbox), frame);
@@ -430,7 +404,7 @@ prefs_dialog_auth_create_dialog(context, auth)
   /*
    * nessusd_port
    */
-  hbox2 = gtk_hbox_new(FALSE, 0);
+  hbox2 = gtk_hbox_new(FALSE, 4);
   gtk_widget_show(hbox2);
 
   auth->port = gtk_entry_new();
@@ -460,14 +434,10 @@ prefs_dialog_auth_create_dialog(context, auth)
   gtk_widget_show(frame);
   gtk_box_pack_start_defaults(GTK_BOX(dialog_vbox), frame);
 
-  hbox = gtk_hbox_new(TRUE, 8);
-  gtk_container_add(GTK_CONTAINER(frame), hbox);
-#else
-  hbox = gtk_hbox_new(TRUE, 8);
-  gtk_container_add(GTK_CONTAINER(dialog_vbox), hbox);
-#endif /* USE_AF_INET */
-  gtk_widget_show(hbox);
-  gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
+  vbox = gtk_vbox_new(TRUE, 8);
+  gtk_container_add(GTK_CONTAINER(frame), vbox);
+  gtk_widget_show(vbox);
+  gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
 
   /*
    * nessusd_user
@@ -477,7 +447,7 @@ prefs_dialog_auth_create_dialog(context, auth)
   gtk_entry_set_text(GTK_ENTRY(auth->username),
       prefs_get_string(context, "nessusd_user"));
   gtk_tooltips_set_tip(tooltips, auth->username, HLP_LOGIN_USER, "");
-  gtk_box_pack_start_defaults(GTK_BOX(hbox),
+  gtk_box_pack_start_defaults(GTK_BOX(vbox),
       prefs_dialog_auth_vbox(_("Login:"), auth->username));
 
   /*
@@ -487,37 +457,11 @@ prefs_dialog_auth_create_dialog(context, auth)
   gtk_widget_show(auth->password);
   gtk_entry_set_visibility(GTK_ENTRY(auth->password), FALSE);
   /* gtk_tooltips_set_tip(tooltips, auth->password, HLP_LOGIN_PASSWORD, ""); */
-  gtk_box_pack_start_defaults(GTK_BOX(hbox),
+  gtk_box_pack_start_defaults(GTK_BOX(vbox),
       prefs_dialog_auth_vbox(_("Password:"), auth->password));
   gtk_widget_grab_focus(auth->password);
   gtk_entry_set_activates_default(GTK_ENTRY(auth->password), TRUE);
 
-#ifdef NESSUS_ON_SSL
-  frame = gtk_frame_new(_("SSL options"));
-  gtk_widget_show(frame);
-  gtk_box_pack_start_defaults(GTK_BOX(dialog_vbox), frame);
-
-  vbox = gtk_vbox_new(FALSE, 4);
-  gtk_container_add(GTK_CONTAINER(frame), vbox);
-  gtk_widget_show(vbox);
-  gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
-
-  hbox = gtk_hbox_new(TRUE, 8);
-  gtk_widget_show(hbox);
-  gtk_box_pack_start_defaults(GTK_BOX(vbox), hbox);
-
-  /*
-   * use_ssl
-   */
-  auth->use_ssl = gtk_check_button_new_with_mnemonic(
-      _("Use SSL encryption"));
-  gtk_widget_show(auth->use_ssl);
-  gtk_box_pack_start_defaults(GTK_BOX(hbox), auth->use_ssl);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(auth->use_ssl),
-      prefs_get_int(context, "use_ssl") &&
-      strcasecmp(prefs_get_string(context, "ssl_version"), "NONE"));
-  g_signal_connect(G_OBJECT(auth->use_ssl), "toggled",
-      G_CALLBACK(prefs_dialog_auth_update), auth);
 
   /*
    * use_client_cert
@@ -525,7 +469,7 @@ prefs_dialog_auth_create_dialog(context, auth)
   auth->use_client_cert = gtk_check_button_new_with_mnemonic(
       _("Authentication by certi_ficate"));
   gtk_widget_show(auth->use_client_cert);
-  gtk_box_pack_start_defaults(GTK_BOX(hbox), auth->use_client_cert);
+  gtk_box_pack_start_defaults(GTK_BOX(vbox), auth->use_client_cert);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(auth->use_client_cert),
       prefs_get_int(context, "use_client_cert"));
   g_signal_connect(G_OBJECT(auth->use_client_cert), "toggled",
@@ -550,7 +494,6 @@ prefs_dialog_auth_create_dialog(context, auth)
       auth, _("User Key File:"), "key_file", vbox);
 
   prefs_dialog_auth_update(NULL, auth);
-#endif /* NESSUS_ON_SSL */
 }
 
 gboolean
@@ -574,49 +517,36 @@ prefs_dialog_auth_connect_dialog(context, ctrls)
       const char *username;
       const char *password;
       char *err;
-#ifdef NESSUS_ON_SSL
       const char *trusted_ca;
       const char *cert_file;
       const char *key_file;
-      int use_ssl = 0;
       int use_client_cert = 0;
-#endif /* NESSUS_ON_SSL */
 
       efree(&context->passwd);
-#ifdef USE_AF_INET
       if(!(hostname = prefs_dialog_auth_hostname(auth)) ||
 	 (port = prefs_dialog_auth_port(auth)) < 0)
 	continue;
-#endif /* USE_AF_INET */
       if(!(username = prefs_dialog_auth_username(auth)) ||
 	 !(password = prefs_dialog_auth_password(auth)))
 	continue;
 
-#ifdef NESSUS_ON_SSL
-      if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(auth->use_ssl)))
-	use_ssl = 1;
       if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(auth->use_client_cert)))
 	use_client_cert = 1;
 
-      if(use_ssl)
+      if(!(trusted_ca = prefs_dialog_auth_trusted_ca(auth, context)))
+        continue;
+      
+      if(use_client_cert)
       {
-	if(!(trusted_ca = prefs_dialog_auth_trusted_ca(auth, context)))
-	  continue;
-
-	if(use_client_cert)
-	{
-	  if(!(cert_file = prefs_dialog_auth_cert_file(auth)) ||
-	     !(key_file = prefs_dialog_auth_key_file(auth)))
-	    continue;
-	  prefs_set_string(context, "cert_file", cert_file);
-	  prefs_set_string(context, "key_file", key_file);
-	}
-
-	prefs_set_string(context, "trusted_ca", trusted_ca);
+        if(!(cert_file = prefs_dialog_auth_cert_file(auth)) ||
+            !(key_file = prefs_dialog_auth_key_file(auth)))
+          continue;
+        prefs_set_string(context, "cert_file", cert_file);
+        prefs_set_string(context, "key_file", key_file);
       }
-      prefs_set_int(context, "use_ssl", use_ssl);
+      
+      prefs_set_string(context, "trusted_ca", trusted_ca);
       prefs_set_int(context, "use_client_cert", use_client_cert);
-#endif /* NESSUS_ON_SSL */
 
       prefs_set_string(context, "nessusd_host", hostname);
       prefs_set_int(context, "nessusd_port", port);
@@ -636,11 +566,9 @@ prefs_dialog_auth_connect_dialog(context, ctrls)
   }
   arg_set_value(ctrls, "CONTEXT", -1, auth->parent);
   gtk_widget_destroy(auth->dialog);
-#ifdef NESSUS_ON_SSL
   efree(&auth->trusted_ca);
   efree(&auth->cert_file);
   efree(&auth->key_file);
-#endif /* NESSUS_ON_SSL */
   efree(&auth);
 
   return (context->socket >= 0);
@@ -680,12 +608,7 @@ prefs_dialog_auth_disconnect(menuitem, ctrls)
   GtkMenuItem *menuitem;
   gpointer ctrls;
 {
-#ifdef NESSUS_ON_SSL
   close_stream_connection(Context->socket);
-#else
-  shutdown(Context->socket, 2);
-  closesocket(Context->socket);
-#endif
   Context->socket = -1;
   prefs_context_update(Context);
   scopetreeview_connected_update(Context);
